Learn R Programming

pensar (version 0.4.2)

backlinks: Backlink discovery

Description

Find pages that link to a given page via wikilinks. Find backlinks to a page

Scans all markdown files in the vault for [[wikilinks]] that reference the target page.

Usage

backlinks(page, vault = default_vault())

Value

A data.frame with columns source (page name) and

file (path relative to the vault).

Arguments

page

Page name (without .md extension).

vault

Path to the vault directory.

Examples

Run this code
v <- tempfile("vault-")
init_vault(v, rproj = FALSE, agent_instructions = FALSE)
ingest("See [[seed]] for context.", type = "articles",
       source = "demo", vault = v)
backlinks("seed", vault = v)
unlink(v, recursive = TRUE)

Run the code above in your browser using DataLab