Learn R Programming

pensar (version 0.4.2)

ingest_briefing: Briefing ingestion

Description

Generate a saber briefing and ingest it into the vault. Generate and ingest a saber briefing

Calls saber::briefing(project) to produce a project briefing and ingests it into the vault as a briefings raw source. Requires the saber package.

Usage

ingest_briefing(project = NULL, vault = default_vault())

Value

The path to the ingested briefing file, invisibly. Returns

NULL invisibly if saber is not installed or the project cannot be inferred.

Arguments

project

Project name. If NULL, inferred from the git root of the current working directory.

vault

Path to the vault directory.

Examples

Run this code
if (FALSE) {
# Requires saber and a git project so a briefing can be generated.
v <- tempfile("vault-")
init_vault(v, rproj = FALSE, agent_instructions = FALSE)
ingest_briefing(project = "pensar", vault = v)
}

Run the code above in your browser using DataLab