powered by
Regenerate the vault index as a markdown catalog. Update the vault index
Scans all markdown files in the vault and regenerates index.md as a categorized catalog with wikilinks and titles.
index.md
update_index(vault = default_vault())
The path to index.md, invisibly.
Path to the vault directory.
v <- tempfile("vault-") init_vault(v, rproj = FALSE, agent_instructions = FALSE) ingest("Body.", type = "articles", source = "demo", vault = v) update_index(v) unlink(v, recursive = TRUE)
Run the code above in your browser using DataLab